[Libreoffice-commits] core.git: Branch 'distro/collabora/cp-6.2' - sc/source

Tor Lillqvist (via logerrit) logerrit at kemper.freedesktop.org
Fri Sep 20 11:10:20 UTC 2019


 sc/source/ui/view/viewfun5.cxx |    6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

New commits:
commit ea277bb4a8a2fe218e12ff8bd2a46bdc08c6ca26
Author:     Tor Lillqvist <tml at collabora.com>
AuthorDate: Mon Apr 1 15:50:53 2019 +0300
Commit:     Tor Lillqvist <tml at collabora.com>
CommitDate: Fri Sep 20 13:09:30 2019 +0200

    Avoid "Text Import" dialog if invoking Paste() from OLE Automation
    
    Change-Id: Ib12b628eee25273aa489dbbd86004167ca105c0b
    Reviewed-on: https://gerrit.libreoffice.org/79197
    Reviewed-by: Tor Lillqvist <tml at collabora.com>
    Tested-by: Tor Lillqvist <tml at collabora.com>

diff --git a/sc/source/ui/view/viewfun5.cxx b/sc/source/ui/view/viewfun5.cxx
index 0eca9685ad61..96e2f270a783 100644
--- a/sc/source/ui/view/viewfun5.cxx
+++ b/sc/source/ui/view/viewfun5.cxx
@@ -43,6 +43,7 @@
 #include <vcl/transfer.hxx>
 #include <vcl/graph.hxx>
 
+#include <comphelper/automationinvokedzone.hxx>
 #include <comphelper/lok.hxx>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/storagehelper.hxx>
@@ -334,9 +335,10 @@ bool ScViewFunc::PasteDataFormat( SotClipboardFormatId nFormatId,
             else if ((nFormatId == SotClipboardFormatId::STRING || nFormatId == SotClipboardFormatId::STRING_TSVC)
                     && aDataHelper.GetString( nFormatId, *pStrBuffer ))
             {
                 // Do CSV dialog if more than one line.
                 sal_Int32 nDelim = pStrBuffer->indexOf('\n');
-                if (nDelim >= 0 && nDelim != pStrBuffer->getLength () - 1)
+                if (!comphelper::Automation::AutomationInvokedZone::isActive()
+                    && nDelim >= 0 && nDelim != pStrBuffer->getLength () - 1)
                 {
                     vcl::Window* pParent = GetActiveWin();
 
@@ -334,9 +335,10 @@ bool ScViewFunc::PasteDataFormat( SotClipboardFormatId nFormatId,
                     && aDataHelper.GetString( nFormatId, *pStrBuffer ))
             {
-                // Do CSV dialog if more than one line.
+                // Do CSV dialog if more than one line. But not if invoked from Automation.
                 sal_Int32 nDelim = pStrBuffer->indexOf('\n');


More information about the Libreoffice-commits mailing list